Django-Pizza
============

Django Pizza is a simple CMS you that lets you add common content components to 
an existing Django project very easily.

What sets Django Pizza apart from other Content Management Systems:
* Simple and easy to use
* Doesn't take over your project, pick and choose what you want to use
* Minimal dependancies for install
* Manage multiple domains/sites
* Free pizza with every install

